@@ -2,34 +2,34 @@ package Sisimai::Address;
 use feature ':5.10';
 use strict;
 use warnings;
-use Class::Accessor::Lite;
 use Sisimai::RFC5322;
+use Class::Accessor::Lite (
+    'new' => 0,
+    'ro'  => [
+        'address',  # [String] Email address
+        'user',     # [String] local part of the email address
+        'host',     # [String] domain part of the email address
+        'verp',     # [String] VERP
+        'alias',    # [String] alias of the email address
+    ],
+    'rw'  => [
+        'name',     # [String] Display name
+        'comment',  # [String] (Comment)
+    ]
+);
 
-my $Indicators = {
+state $Indicators = {
     'email-address' => (1 << 0),    # <neko@example.org>
     'quoted-string' => (1 << 1),    # "Neko, Nyaan"
     'comment-block' => (1 << 2),    # (neko)
 };
-my $ValidEmail = qr{(?>
+state $ValidEmail = qr{(?>
     (?:([^\s]+|["].+?["]))          # local part
     [@]
     (?:([^@\s]+|[0-9A-Za-z:\.]+))   # domain part
     )
 }x;
-my $Delimiters = { '<' => 1, '>' => 1, '(' => 1, ')' => 1, '"' => 1, ',' => 1 };
-my $roaccessors = [
-    'address',  # [String] Email address
-    'user',     # [String] local part of the email address
-    'host',     # [String] domain part of the email address
-    'verp',     # [String] VERP
-    'alias',    # [String] alias of the email address
-];
-my $rwaccessors = [
-    'name',     # [String] Display name
-    'comment',  # [String] (Comment)
-];
-Class::Accessor::Lite->mk_ro_accessors(@$roaccessors);
-Class::Accessor::Lite->mk_accessors(@$rwaccessors);
+state $Delimiters = { '<' => 1, '>' => 1, '(' => 1, ')' => 1, '"' => 1, ',' => 1 };
 
 sub undisclosed {
     # Return pseudo recipient or sender address
@@ -554,7 +554,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2019 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2020 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
