@@ -4,13 +4,13 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-my $Indicators = __PACKAGE__->INDICATORS;
-my $StartingOf = {
+state $Indicators = __PACKAGE__->INDICATORS;
+state $ReBackbone = qr|^Content-Type:[ ]message/rfc822|m;
+state $StartingOf = {
     'message' => ['Your message'],
-    'rfc822'  => ['Content-Type: message/rfc822'],
     'error'   => ['did not reach the following recipient(s):'],
 };
-my $ErrorCodes = {
+state $ErrorCodes = {
     'onhold' => [
         '000B099C', # Host Unknown, Message exceeds size limit, ...
         '000B09AA', # Unable to relay for, Message exceeds size limit,...
@@ -26,11 +26,11 @@ my $ErrorCodes = {
     'networkerror' => [
         '00120270', # Too Many Hops
     ],
-    'contenterr' => [
+    'contenterror' => [
         '00050311', # Conversion to Internet format failed
         '000502CC', # Conversion to Internet format failed
     ],
-    'securityerr' => [
+    'securityerror' => [
         '000B0981', # 502 Server does not support AUTH
     ],
     'filtered' => [
@@ -38,29 +38,22 @@ my $ErrorCodes = {
     ],
 };
 
-# X-MS-TNEF-Correlator: <00000000000000000000000000000000000000@example.com>
-# X-Mailer: Internet Mail Service (5.5.1960.3)
-# X-MS-Embedded-Report:
-sub headerlist  { return ['x-ms-embedded-report', 'x-mimeole'] };
 sub description { 'Microsoft Exchange Server 2003' }
 sub make {
     # Detect an error from Microsoft Exchange Server 2003
-    # @param         [Hash] mhead       Message headers of a bounce email
-    # @options mhead [String] from      From header
-    # @options mhead [String] date      Date header
-    # @options mhead [String] subject   Subject header
-    # @options mhead [Array]  received  Received headers
-    # @options mhead [String] others    Other required headers
-    # @param         [String] mbody     Message body of a bounce email
-    # @return        [Hash, Undef]      Bounce data list and message/rfc822 part
-    #                                   or Undef if it failed to parse or the
-    #                                   arguments are missing
+    # @param    [Hash] mhead    Message headers of a bounce email
+    # @param    [String] mbody  Message body of a bounce email
+    # @return   [Hash]          Bounce data list and message/rfc822 part
+    # @return   [Undef]         failed to parse or the arguments are missing
     # @since v4.1.1
     my $class = shift;
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
     my $match = 0;
 
+    # X-MS-TNEF-Correlator: <00000000000000000000000000000000000000@example.com>
+    # X-Mailer: Internet Mail Service (5.5.1960.3)
+    # X-MS-Embedded-Report:
     $match ||= 1 if defined $mhead->{'x-ms-embedded-report'};
     EXCHANGE_OR_NOT: while(1) {
         # Check the value of X-Mailer header
@@ -93,9 +86,7 @@ sub make {
     return undef unless $match;
 
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
-    my $rfc822part = '';    # (String) message/rfc822-headers part
-    my $rfc822list = [];    # (Array) Each line in message/rfc822 part string
-    my $blanklines = 0;     # (Integer) The number of blank lines
+    my $emailsteak = Sisimai::RFC5322->fillet($mbody, $ReBackbone);
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $statuspart = 0;     # (Integer) Flag, 1 = have got delivery status part.
@@ -107,116 +98,94 @@ sub make {
     };
     my $v = undef;
 
-    for my $e ( split("\n", $$mbody) ) {
-        # Read each line between the start of the message and the start of rfc822 part.
+    for my $e ( split("\n", $emailsteak->[0]) ) {
+        # Read error messages and delivery status lines from the head of the email
+        # to the previous line of the beginning of the original message.
         unless( $readcursor ) {
-            # Beginning of the bounce message or delivery status part
-            if( index($e, $StartingOf->{'message'}->[0]) == 0 ) {
-                $readcursor |= $Indicators->{'deliverystatus'};
-                next;
-            }
+            # Beginning of the bounce message or message/delivery-status part
+            $readcursor |= $Indicators->{'deliverystatus'} if index($e, $StartingOf->{'message'}->[0]) == 0;
+            next;
         }
+        next unless $readcursor & $Indicators->{'deliverystatus'};
+        next if $statuspart;
 
-        unless( $readcursor & $Indicators->{'message-rfc822'} ) {
-            # Beginning of the original message part
-            if( index($e, $StartingOf->{'rfc822'}->[0]) == 0 ) {
-                $readcursor |= $Indicators->{'message-rfc822'};
-                next;
-            }
-        }
+        if( $connvalues == scalar(keys %$connheader) ) {
+            # did not reach the following recipient(s):
+            #
+            # kijitora@example.co.jp on Thu, 29 Apr 2007 16:51:51 -0500
+            #     The recipient name is not recognized
+            #     The MTS-ID of the original message is: c=jp;a= ;p=neko
+            # ;l=EXCHANGE000000000000000000
+            #     MSEXCH:IMS:KIJITORA CAT:EXAMPLE:EXCHANGE 0 (000C05A6) Unknown Recipient
+            # mikeneko@example.co.jp on Thu, 29 Apr 2007 16:51:51 -0500
+            #     The recipient name is not recognized
+            #     The MTS-ID of the original message is: c=jp;a= ;p=neko
+            # ;l=EXCHANGE000000000000000000
+            #     MSEXCH:IMS:KIJITORA CAT:EXAMPLE:EXCHANGE 0 (000C05A6) Unknown Recipient
+            $v = $dscontents->[-1];
 
-        if( $readcursor & $Indicators->{'message-rfc822'} ) {
-            # Inside of the original message
-            unless( length $e ) {
-                last if ++$blanklines > 1;
-                next;
-            }
-            push @$rfc822list, $e;
-
-        } else {
-            # Error message part
-            next unless $readcursor & $Indicators->{'deliverystatus'};
-            next if $statuspart;
-
-            if( $connvalues == scalar(keys %$connheader) ) {
-                # did not reach the following recipient(s):
-                #
+            if( $e =~ /\A[ \t]*([^ ]+[@][^ ]+) on[ \t]*.*\z/ ||
+                $e =~ /\A[ \t]*.+(?:SMTP|smtp)=([^ ]+[@][^ ]+) on[ \t]*.*\z/ ) {
                 # kijitora@example.co.jp on Thu, 29 Apr 2007 16:51:51 -0500
-                #     The recipient name is not recognized
-                #     The MTS-ID of the original message is: c=jp;a= ;p=neko
-                # ;l=EXCHANGE000000000000000000
-                #     MSEXCH:IMS:KIJITORA CAT:EXAMPLE:EXCHANGE 0 (000C05A6) Unknown Recipient
-                # mikeneko@example.co.jp on Thu, 29 Apr 2007 16:51:51 -0500
-                #     The recipient name is not recognized
-                #     The MTS-ID of the original message is: c=jp;a= ;p=neko
-                # ;l=EXCHANGE000000000000000000
-                #     MSEXCH:IMS:KIJITORA CAT:EXAMPLE:EXCHANGE 0 (000C05A6) Unknown Recipient
-                $v = $dscontents->[-1];
+                #   kijitora@example.com on 4/29/99 9:19:59 AM
+                if( $v->{'recipient'} ) {
+                    # There are multiple recipient addresses in the message body.
+                    push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
+                    $v = $dscontents->[-1];
+                }
+                $v->{'recipient'} = $1;
+                $v->{'msexch'} = 0;
+                $recipients++;
 
-                if( $e =~ /\A[ \t]*([^ ]+[@][^ ]+) on[ \t]*.*\z/ ||
-                    $e =~ /\A[ \t]*.+(?:SMTP|smtp)=([^ ]+[@][^ ]+) on[ \t]*.*\z/ ) {
-                    # kijitora@example.co.jp on Thu, 29 Apr 2007 16:51:51 -0500
-                    #   kijitora@example.com on 4/29/99 9:19:59 AM
-                    if( $v->{'recipient'} ) {
-                        # There are multiple recipient addresses in the message body.
-                        push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
-                        $v = $dscontents->[-1];
-                    }
-                    $v->{'recipient'} = $1;
-                    $v->{'msexch'} = 0;
-                    $recipients++;
+            } elsif( $e =~ /\A[ \t]+(MSEXCH:.+)\z/ ) {
+                #     MSEXCH:IMS:KIJITORA CAT:EXAMPLE:EXCHANGE 0 (000C05A6) Unknown Recipient
+                $v->{'diagnosis'} .= $1;
 
-                } elsif( $e =~ /\A[ \t]+(MSEXCH:.+)\z/ ) {
-                    #     MSEXCH:IMS:KIJITORA CAT:EXAMPLE:EXCHANGE 0 (000C05A6) Unknown Recipient
-                    $v->{'diagnosis'} .= $1;
+            } else {
+                next if $v->{'msexch'};
+                if( index($v->{'diagnosis'}, 'MSEXCH:') == 0 ) {
+                    # Continued from MEEXCH in the previous line
+                    $v->{'msexch'} = 1;
+                    $v->{'diagnosis'} .= ' '.$e;
+                    $statuspart = 1;
 
                 } else {
-                    next if $v->{'msexch'};
-                    if( index($v->{'diagnosis'}, 'MSEXCH:') == 0 ) {
-                        # Continued from MEEXCH in the previous line
-                        $v->{'msexch'} = 1;
-                        $v->{'diagnosis'} .= ' '.$e;
-                        $statuspart = 1;
-
-                    } else {
-                        # Error message in the body part
-                        $v->{'alterrors'} .= ' '.$e;
-                    }
+                    # Error message in the body part
+                    $v->{'alterrors'} .= ' '.$e;
                 }
-            } else {
-                # Your message
-                #
+            }
+        } else {
+            # Your message
+            #
+            #  To:      shironeko@example.jp
+            #  Subject: ...
+            #  Sent:    Thu, 29 Apr 2010 18:14:35 +0000
+            #
+            if( $e =~ /\A[ \t]+To:[ \t]+(.+)\z/ ) {
                 #  To:      shironeko@example.jp
+                next if $connheader->{'to'};
+                $connheader->{'to'} = $1;
+                $connvalues++;
+
+            } elsif( $e =~ /\A[ \t]+Subject:[ \t]+(.+)\z/ ) {
                 #  Subject: ...
+                next if length $connheader->{'subject'};
+                $connheader->{'subject'} = $1;
+                $connvalues++;
+
+            } elsif( $e =~ m|\A[ \t]+Sent:[ \t]+([A-Z][a-z]{2},.+[-+]\d{4})\z| ||
+                     $e =~ m|\A[ \t]+Sent:[ \t]+(\d+[/]\d+[/]\d+[ \t]+\d+:\d+:\d+[ \t].+)|) {
                 #  Sent:    Thu, 29 Apr 2010 18:14:35 +0000
-                #
-                if( $e =~ /\A[ \t]+To:[ \t]+(.+)\z/ ) {
-                    #  To:      shironeko@example.jp
-                    next if $connheader->{'to'};
-                    $connheader->{'to'} = $1;
-                    $connvalues++;
-
-                } elsif( $e =~ /\A[ \t]+Subject:[ \t]+(.+)\z/ ) {
-                    #  Subject: ...
-                    next if length $connheader->{'subject'};
-                    $connheader->{'subject'} = $1;
-                    $connvalues++;
-
-                } elsif( $e =~ m|\A[ \t]+Sent:[ \t]+([A-Z][a-z]{2},.+[-+]\d{4})\z| ||
-                         $e =~ m|\A[ \t]+Sent:[ \t]+(\d+[/]\d+[/]\d+[ \t]+\d+:\d+:\d+[ \t].+)|) {
-                    #  Sent:    Thu, 29 Apr 2010 18:14:35 +0000
-                    #  Sent:    4/29/99 9:19:59 AM
-                    next if $connheader->{'date'};
-                    $connheader->{'date'} = $1;
-                    $connvalues++;
-                }
+                #  Sent:    4/29/99 9:19:59 AM
+                next if $connheader->{'date'};
+                $connheader->{'date'} = $1;
+                $connvalues++;
             }
         } # End of error message part
     }
     return undef unless $recipients;
 
     for my $e ( @$dscontents ) {
-        $e->{'agent'}     = __PACKAGE__->smtpagent;
         $e->{'diagnosis'} = Sisimai::String->sweep($e->{'diagnosis'});
         delete $e->{'msexch'};
 
@@ -244,14 +213,13 @@ sub make {
         delete $e->{'alterrors'};
     }
 
-    unless( @$rfc822list ) {
+    unless( length $emailsteak->[1] ) {
         # When original message does not included in the bounce message
-        push @$rfc822list, 'From: '.$connheader->{'to'};
-        push @$rfc822list, 'Date: '.$connheader->{'date'};
-        push @$rfc822list, 'Subject: '.$connheader->{'subject'};
+        $emailsteak->[1] .= sprintf("From: %s\n", $connheader->{'to'});
+        $emailsteak->[1] .= sprintf("Date: %s\n", $connheader->{'date'});
+        $emailsteak->[1] .= sprintf("Subject: %s\n", $connheader->{'subject'});
     }
-    $rfc822part = Sisimai::RFC5322->weedout($rfc822list);
-    return { 'ds' => $dscontents, 'rfc822' => $$rfc822part };
+    return { 'ds' => $dscontents, 'rfc822' => $emailsteak->[1] };
 }
 
 1;
@@ -282,12 +250,6 @@ C<description()> returns description string of this module.
 
     print Sisimai::Lhost::Exchange2003->description;
 
-=head2 C<B<smtpagent()>>
-
-C<smtpagent()> returns MTA name.
-
-    print Sisimai::Lhost::Exchange2003->smtpagent;
-
 =head2 C<B<make(I<header data>, I<reference to body string>)>>
 
 
@@ -300,7 +262,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2019 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2020 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
