@@ -4,16 +4,16 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-my $Indicators = __PACKAGE__->INDICATORS;
-my $ReBackbone = qr|^Content-Type:[ ]message/rfc822|m;
-my $MarkingsOf = {
+state $Indicators = __PACKAGE__->INDICATORS;
+state $ReBackbone = qr|^Content-Type:[ ]message/rfc822|m;
+state $MarkingsOf = {
     'message' => qr/\AYour[ ]mail[ ](?:
          sent[ ]on:?[ ][A-Z][a-z]{2}[,]
         |attempted[ ]to[ ]be[ ]delivered[ ]on:?[ ][A-Z][a-z]{2}[,]
         )
     /x,
 };
-my $MessagesOf = {
+state $MessagesOf = {
     'mailboxfull' => ['As their mailbox is full'],
     'norelaying'  => ['Due to the following SMTP relay error'],
     'hostunknown' => ['As the remote domain doesnt exist'],
@@ -22,16 +22,10 @@ my $MessagesOf = {
 sub description { 'au by KDDI: https://www.au.kddi.com' }
 sub make {
     # Detect an error from au by KDDI
-    # @param         [Hash] mhead       Message headers of a bounce email
-    # @options mhead [String] from      From header
-    # @options mhead [String] date      Date header
-    # @options mhead [String] subject   Subject header
-    # @options mhead [Array]  received  Received headers
-    # @options mhead [String] others    Other required headers
-    # @param         [String] mbody     Message body of a bounce email
-    # @return        [Hash, Undef]      Bounce data list and message/rfc822 part
-    #                                   or Undef if it failed to parse or the
-    #                                   arguments are missing
+    # @param    [Hash] mhead    Message headers of a bounce email
+    # @param    [String] mbody  Message body of a bounce email
+    # @return   [Hash]          Bounce data list and message/rfc822 part
+    # @return   [Undef]         failed to parse or the arguments are missing
     # @since v4.0.0
     my $class = shift;
     my $mhead = shift // return undef;
@@ -89,7 +83,6 @@ sub make {
     return undef unless $recipients;
 
     for my $e ( @$dscontents ) {
-        $e->{'agent'}     = __PACKAGE__->smtpagent;
         $e->{'diagnosis'} = Sisimai::String->sweep($e->{'diagnosis'});
 
         if( defined $mhead->{'x-spasign'} && $mhead->{'x-spasign'} eq 'NG' ) {
@@ -142,12 +135,6 @@ C<description()> returns description string of this module.
 
     print Sisimai::Lhost::KDDI->description;
 
-=head2 C<B<smtpagent()>>
-
-C<smtpagent()> returns MTA name.
-
-    print Sisimai::Lhost::KDDI->smtpagent;
-
 =head2 C<B<make(I<header data>, I<reference to body string>)>>
 
 C<make()> method parses a bounced email and return results as a array reference.
