@@ -4,10 +4,10 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-my $Indicators = __PACKAGE__->INDICATORS;
-my $ReBackbone = qr|^Content-Type:[ ]message/rfc822|m;
-my $StartingOf = { 'message' => ['--- The following addresses had delivery problems ---'] };
-my $ReFailures = {
+state $Indicators = __PACKAGE__->INDICATORS;
+state $ReBackbone = qr|^Content-Type:[ ]message/rfc822|m;
+state $StartingOf = { 'message' => ['--- The following addresses had delivery problems ---'] };
+state $ReFailures = {
     'userunknown' => qr{(?:
          [ ]User[ ][(].+[@].+[)][ ]unknown[.][ ]
         |550[ ]Unknown[ ]user[ ][^ ]+[@][^ ]+
@@ -17,26 +17,19 @@ my $ReFailures = {
     }x,
 };
 
-# X-NAI-Header: Modified by McAfee Email and Web Security Virtual Appliance
-sub headerlist  { return ['x-nai-header'] }
 sub description { 'McAfee Email Appliance' }
 sub make {
     # Detect an error from McAfee
-    # @param         [Hash] mhead       Message headers of a bounce email
-    # @options mhead [String] from      From header
-    # @options mhead [String] date      Date header
-    # @options mhead [String] subject   Subject header
-    # @options mhead [Array]  received  Received headers
-    # @options mhead [String] others    Other required headers
-    # @param         [String] mbody     Message body of a bounce email
-    # @return        [Hash, Undef]      Bounce data list and message/rfc822 part
-    #                                   or Undef if it failed to parse or the
-    #                                   arguments are missing
+    # @param    [Hash] mhead    Message headers of a bounce email
+    # @param    [String] mbody  Message body of a bounce email
+    # @return   [Hash]          Bounce data list and message/rfc822 part
+    # @return   [Undef]         failed to parse or the arguments are missing
     # @since v4.1.1
     my $class = shift;
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
 
+    # X-NAI-Header: Modified by McAfee Email and Web Security Virtual Appliance
     return undef unless defined $mhead->{'x-nai-header'};
     return undef unless index($mhead->{'x-nai-header'}, 'Modified by McAfee') > -1;
     return undef unless $mhead->{'subject'} eq 'Delivery Status';
@@ -109,7 +102,6 @@ sub make {
     return undef unless $recipients;
 
     for my $e ( @$dscontents ) {
-        $e->{'agent'}     = __PACKAGE__->smtpagent;
         $e->{'diagnosis'} = Sisimai::String->sweep($e->{'diagnosis'} || $diagnostic);
 
         SESSION: for my $r ( keys %$ReFailures ) {
@@ -149,12 +141,6 @@ C<description()> returns description string of this module.
 
     print Sisimai::Lhost::McAfee->description;
 
-=head2 C<B<smtpagent()>>
-
-C<smtpagent()> returns MTA name.
-
-    print Sisimai::Lhost::McAfee->smtpagent;
-
 =head2 C<B<make(I<header data>, I<reference to body string>)>>
 
 C<make()> method parses a bounced email and return results as a array reference.
