@@ -4,9 +4,9 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-my $Indicators = __PACKAGE__->INDICATORS;
-my $ReBackbone = qr<^Content-Type:[ ](?:message/rfc822|text/rfc822-headers)>m;
-my $StartingOf = {
+state $Indicators = __PACKAGE__->INDICATORS;
+state $ReBackbone = qr<^Content-Type:[ ](?:message/rfc822|text/rfc822-headers)>m;
+state $StartingOf = {
     #   savemail.c:1040|if (printheader && !putline("   ----- Transcript of session follows -----\n",
     #   savemail.c:1041|          mci))
     #   savemail.c:1042|  goto writeerr;
@@ -21,27 +21,17 @@ my $StartingOf = {
 sub description { 'V8Sendmail: /usr/sbin/sendmail' }
 sub make {
     # Parse bounce messages from Sendmail
-    # @param         [Hash] mhead       Message header of a bounce email
-    # @options mhead [String] from      From header
-    # @options mhead [String] date      Date header
-    # @options mhead [String] subject   Subject header
-    # @options mhead [Array]  received  Received headers
-    # @options mhead [String] others    Other required headers
-    # @param         [String] mbody     Message body of a bounce email
-    # @return        [Hash, Undef]      Bounce data list and message/rfc822 part
-    #                                   or Undef if it failed to parse or the
-    #                                   arguments are missing
+    # @param    [Hash] mhead    Message headers of a bounce email
+    # @param    [String] mbody  Message body of a bounce email
+    # @return   [Hash]          Bounce data list and message/rfc822 part
+    # @return   [Undef]         failed to parse or the arguments are missing
     # @since v4.0.0
     my $class = shift;
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
 
     return undef unless $mhead->{'subject'} =~ /(?:see transcript for details\z|\AWarning: )/;
-    unless( lc($mhead->{'subject'}) =~ /\A[ \t]*fwd?:/ ) {
-        # Fwd: Returned mail: see transcript for details
-        # Do not execute this code if the bounce mail is a forwarded message.
-        return undef unless index($mhead->{'from'}, 'Mail Delivery Subsystem') > -1;
-    }
+    return undef if $mhead->{'x-aol-ip'};   # X-AOL-IP is a header defined in AOL
 
     require Sisimai::RFC1894;
     my $fieldtable = Sisimai::RFC1894->FIELDTABLE;
@@ -171,11 +161,10 @@ sub make {
 
     for my $e ( @$dscontents ) {
         # Set default values if each value is empty.
-        $e->{'lhost'}    ||= $permessage->{'rhost'};
-        map { $e->{ $_ } ||= $permessage->{ $_ } || '' } keys %$permessage;
-        $e->{'agent'}      = __PACKAGE__->smtpagent;
-        $e->{'command'}  ||= $commandtxt || '';
-        $e->{'command'}  ||= 'EHLO' if scalar @$esmtpreply;
+        $e->{'lhost'}   ||= $permessage->{'rhost'};
+        $e->{ $_ } ||= $permessage->{ $_ } || '' for keys %$permessage;
+        $e->{'command'} ||= $commandtxt || '';
+        $e->{'command'} ||= 'EHLO' if scalar @$esmtpreply;
 
         if( exists $anotherset->{'diagnosis'} && $anotherset->{'diagnosis'} ) {
             # Copy alternative error message
@@ -232,12 +221,6 @@ C<description()> returns description string of this module.
 
     print Sisimai::Lhost::Sendmail->description;
 
-=head2 C<B<smtpagent()>>
-
-C<smtpagent()> returns MTA name.
-
-    print Sisimai::Lhost::Sendmail->smtpagent;
-
 =head2 C<B<make(I<header data>, I<reference to body string>)>>
 
 C<make()> method parses a bounced email and return results as a array reference.
