@@ -4,33 +4,25 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-my $Indicators = __PACKAGE__->INDICATORS;
-my $ReBackbone = qr|^Content-Type:[ ]message/rfc822|m;
-my $StartingOf = { 'message' => ['Your message could not be sent.'] };
+state $Indicators = __PACKAGE__->INDICATORS;
+state $ReBackbone = qr|^Content-Type:[ ]message/rfc822|m;
+state $StartingOf = { 'message' => ['Your message could not be sent.'] };
 
-# X-SEF-ZeroHour-RefID: fgs=000000000
-# X-SEF-Processed: 0_0_0_000__2010_04_29_23_34_45
-# X-Mailer: SurfControl E-mail Filter
-sub headerlist  { return ['x-sef-processed', 'x-mailer'] }
 sub description { 'WebSense SurfControl' }
 sub make {
     # Detect an error from SurfControl
-    # @param         [Hash] mhead       Message headers of a bounce email
-    # @options mhead [String] from      From header
-    # @options mhead [String] date      Date header
-    # @options mhead [String] subject   Subject header
-    # @options mhead [Array]  received  Received headers
-    # @options mhead [String] others    Other required headers
-    # @param         [String] mbody     Message body of a bounce email
-    # @return        [Hash, Undef]      Bounce data list and message/rfc822 part
-    #                                   or Undef if it failed to parse or the
-    #                                   arguments are missing
+    # @param    [Hash] mhead    Message headers of a bounce email
+    # @param    [String] mbody  Message body of a bounce email
+    # @return   [Hash]          Bounce data list and message/rfc822 part
+    # @return   [Undef]         failed to parse or the arguments are missing
     # @since v4.1.2
     my $class = shift;
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
 
-    # 'from'     => qr/ [(]Mail Delivery System[)]\z/,
+    # X-SEF-ZeroHour-RefID: fgs=000000000
+    # X-SEF-Processed: 0_0_0_000__2010_04_29_23_34_45
+    # X-Mailer: SurfControl E-mail Filter
     return undef unless $mhead->{'x-sef-processed'};
     return undef unless $mhead->{'x-mailer'};
     return undef unless $mhead->{'x-mailer'} eq 'SurfControl E-mail Filter';
@@ -107,10 +99,7 @@ sub make {
     }
     return undef unless $recipients;
 
-    for my $e ( @$dscontents ) {
-        $e->{'diagnosis'} = Sisimai::String->sweep($e->{'diagnosis'});
-        $e->{'agent'}     = __PACKAGE__->smtpagent;
-    }
+    $_->{'diagnosis'} = Sisimai::String->sweep($_->{'diagnosis'}) for @$dscontents;
     return { 'ds' => $dscontents, 'rfc822' => $emailsteak->[1] };
 }
 
@@ -140,12 +129,6 @@ C<description()> returns description string of this module.
 
     print Sisimai::Lhost::SurfControl->description;
 
-=head2 C<B<smtpagent()>>
-
-C<smtpagent()> returns MTA name.
-
-    print Sisimai::Lhost::SurfControl->smtpagent;
-
 =head2 C<B<make(I<header data>, I<reference to body string>)>>
 
 C<make()> method parses a bounced email and return results as a array reference.
