@@ -4,34 +4,26 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-my $Indicators = __PACKAGE__->INDICATORS;
-my $ReBackbone = qr|^--- Below this line is a copy of the message[.]|m;
-my $StartingOf = { 'message' => ['Sorry, we were unable to deliver your message'] };
+state $Indicators = __PACKAGE__->INDICATORS;
+state $ReBackbone = qr|^--- Below this line is a copy of the message[.]|m;
+state $StartingOf = { 'message' => ['Sorry, we were unable to deliver your message'] };
 
-# X-YMailISG: YtyUVyYWLDsbDh...
-# X-YMail-JAS: Pb65aU4VM1mei...
-# X-YMail-OSG: bTIbpDEVM1lHz...
-# X-Originating-IP: [192.0.2.9]
-sub headerlist  { return ['x-ymailisg'] }
 sub description { 'Yahoo! MAIL: https://www.yahoo.com' }
 sub make {
     # Detect an error from Yahoo! MAIL
-    # @param         [Hash] mhead       Message headers of a bounce email
-    # @options mhead [String] from      From header
-    # @options mhead [String] date      Date header
-    # @options mhead [String] subject   Subject header
-    # @options mhead [Array]  received  Received headers
-    # @options mhead [String] others    Other required headers
-    # @param         [String] mbody     Message body of a bounce email
-    # @return        [Hash, Undef]      Bounce data list and message/rfc822 part
-    #                                   or Undef if it failed to parse or the
-    #                                   arguments are missing
+    # @param    [Hash] mhead    Message headers of a bounce email
+    # @param    [String] mbody  Message body of a bounce email
+    # @return   [Hash]          Bounce data list and message/rfc822 part
+    # @return   [Undef]         failed to parse or the arguments are missing
     # @since v4.1.3
     my $class = shift;
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
 
-    # 'subject' => qr/\AFailure Notice\z/,
+    # X-YMailISG: YtyUVyYWLDsbDh...
+    # X-YMail-JAS: Pb65aU4VM1mei...
+    # X-YMail-OSG: bTIbpDEVM1lHz...
+    # X-Originating-IP: [192.0.2.9]
     return undef unless $mhead->{'x-ymailisg'};
 
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
@@ -102,7 +94,6 @@ sub make {
     for my $e ( @$dscontents ) {
         $e->{'diagnosis'} =~ y/\n/ /;
         $e->{'diagnosis'} =  Sisimai::String->sweep($e->{'diagnosis'});
-        $e->{'agent'}     =  __PACKAGE__->smtpagent;
         $e->{'command'} ||=  'RCPT' if $e->{'diagnosis'} =~ /[<].+[@].+[>]/;
     }
     return { 'ds' => $dscontents, 'rfc822' => $emailsteak->[1] };
@@ -134,12 +125,6 @@ C<description()> returns description string of this module.
 
     print Sisimai::Lhost::Yahoo->description;
 
-=head2 C<B<smtpagent()>>
-
-C<smtpagent()> returns MTA name.
-
-    print Sisimai::Lhost::Yahoo->smtpagent;
-
 =head2 C<B<make(I<header data>, I<reference to body string>)>>
 
 C<make()> method parses a bounced email and return results as a array reference.
