@@ -2,41 +2,42 @@ package Sisimai::Mail;
 use feature ':5.10';
 use strict;
 use warnings;
-use Class::Accessor::Lite;
-
-my $roaccessors = [
-    'path',     # [String] path to mbox or Maildir/
-    'type',     # [String] Data type: mailbox, maildir, or stdin
-];
-my $rwaccessors = [
-    'mail',     # [Sisimai::Mail::[Mbox,Maildir,Memory,STDIO] Object
-];
-Class::Accessor::Lite->mk_accessors(@$rwaccessors);
-Class::Accessor::Lite->mk_ro_accessors(@$roaccessors);
+use Class::Accessor::Lite (
+    'new' => 0,
+    'ro'  => [
+        'path',     # [String] path to mbox or Maildir/
+        'kind',     # [String] Data type: mailbox, maildir, stdin, or memory
+    ],
+    'rw'  => [
+        'data',     # [Sisimai::Mail::[Mbox,Maildir,Memory,STDIO] Object
+    ]
+);
+state $Until = 'v4.25.10';
 
 sub new {
     # Constructor of Sisimai::Mail
-    # @param    [String] argv1         Path to mbox or Maildir/
-    # @return   [Sisimai::Mail, Undef] Object or Undef if the argument was wrong
+    # @param    [String] argv1  Path to mbox or Maildir/
+    # @return   [Sisimai::Mail] Object
+    #           [Undef]         The argument is wrong
     my $class = shift;
     my $argv1 = shift;
     my $klass = undef;
     my $loads = 'Sisimai/Mail/';
-    my $param = { 'type' => '', 'mail' => undef, 'path' => $argv1 };
+    my $param = { 'kind' => '', 'data' => undef, 'path' => $argv1 };
 
     # The argumenet is a mailbox or a Maildir/.
     if( -f $argv1 ) {
         # The argument is a file, it is an mbox or email file in Maildir/
         $klass  = __PACKAGE__.'::Mbox';
         $loads .= 'Mbox.pm';
-        $param->{'type'} = 'mailbox';
+        $param->{'kind'} = 'mailbox';
         $param->{'path'} = $argv1;
 
     } elsif( -d $argv1 ) {
         # The agument is not a file, it is a Maildir/
         $klass  = __PACKAGE__.'::Maildir';
         $loads .= 'Maildir.pm';
-        $param->{'type'} = 'maildir';
+        $param->{'kind'} = 'maildir';
 
     } else {
         # The argumen1 neither a mailbox nor a Maildir/.
@@ -44,32 +45,42 @@ sub new {
             # Read from STDIN
             $klass  = __PACKAGE__.'::STDIN';
             $loads .= 'STDIN.pm';
-            $param->{'type'} = 'stdin';
+            $param->{'kind'} = 'stdin';
 
         } elsif( ref($argv1) eq 'SCALAR' ) {
             # Read from a variable as a scalar reference
             $klass  = __PACKAGE__.'::Memory';
             $loads .= 'Memory.pm';
-            $param->{'type'} = 'memory';
+            $param->{'kind'} = 'memory';
             $param->{'path'} = 'MEMORY';
         }
     }
     return undef unless $klass;
 
     require $loads;
-    $param->{'mail'} = $klass->new($argv1);
+    $param->{'data'} = $klass->new($argv1);
 
     return bless($param, __PACKAGE__);
 }
 
+sub mail {
+    my $self = shift;
+    printf(STDERR " ***warning: %s->mail will be removed at %s. Use %s->data instead\n", __PACKAGE__, $Until, __PACKAGE__);
+    return $self->data;
+}
+
+sub type {
+    my $self = shift;
+    printf(STDERR " ***warning: %s->type will be removed at %s. Use %s->kind instead\n", __PACKAGE__, $Until, __PACKAGE__);
+    return $self->kind;
+}
+
 sub read {
-    # Mbox/Maildir reader, works as an iterator.
+    # Alias method of Sisimai::Mail::*->read()
     # @return   [String] Contents of mbox/Maildir
     my $self = shift;
-    my $mail = $self->{'mail'};
-
-    return undef unless ref $mail;
-    return $mail->read;
+    return undef unless ref $self->{'data'};
+    return $self->{'data'}->read;
 }
 
 sub close {
@@ -77,9 +88,10 @@ sub close {
     # @return   [Integer] 0: Mail handle is not defined
     #                     1: Successfully closed the handle
     my $self = shift;
-    return 0 unless $self->{'mail'}->{'handle'};
+    printf(STDERR " ***warning: %s->close will be removed at %s. The handle automatically closes at the EOF\n", __PACKAGE__, $Until);
+    return 0 unless $self->{'data'}->{'handle'};
 
-    $self->{'mail'}->{'handle'} = undef;
+    $self->{'data'}->{'handle'} = undef;
     return 1;
 }
 
@@ -115,9 +127,10 @@ Sisimai::Mail - Handler of Mbox/Maildir for reading each mail.
 
 =head1 DESCRIPTION
 
-Sisimai::Mail is a handler for reading a UNIX mbox, a Maildir, a bounce object
-as a JSON string, or any email message input from STDIN, variable.
-It is a wrapper class of the following child classes:
+Sisimai::Mail is a handler for reading a UNIX mbox, a Maildir, or any email
+message input from STDIN, variable. It is a wrapper class of the following 
+child classes:
+
     * Sisimai::Mail::Mbox
     * Sisimai::Mail::Maildir
     * Sisimai::Mail::STDIN
@@ -144,9 +157,9 @@ C<path()> returns the path to mbox or Maildir.
 
 =head2 C<B<mbox()>>
 
-C<type()> Returns the name of data type
+C<kind()> Returns the name of data type
 
-    print $mailbox->type;   # mailbox or maildir, or stdin.
+    print $mailbox->kind;   # mailbox or maildir, stdin, or memory.
 
 =head2 C<B<mail()>>
 
@@ -179,7 +192,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016,2018 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018-2020 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
