@@ -3,11 +3,12 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-my $RhostClass = {
-    qr/(?:aspmx|gmail-smtp-in)[.]l[.]google[.]com\z/  => 'GoogleApps',
+state $RhostClass = {
     qr/[.](?:prod|protection)[.]outlook[.]com\z/      => 'ExchangeOnline',
-    qr/\A(?:smtp|mailstore1)[.]secureserver[.]net\z/  => 'GoDaddy',
     qr/\b(?>laposte[.]net|(?:orange|wanadoo)[.]fr)\z/ => 'FrancePTT',
+    qr/\A(?:smtp|mailstore1)[.]secureserver[.]net\z/  => 'GoDaddy',
+    qr/(?:aspmx|gmail-smtp-in)[.]l[.]google[.]com\z/  => 'GoogleApps',
+    qr/[.]email[.]ua\z/                               => 'IUA',
     qr/[.](?:ezweb[.]ne[.]jp|au[.]com)\z/             => 'KDDI',
     qr/mx[0-9]+[.]qq[.]com\z/                         => 'TencentQQ',
 };
@@ -34,7 +35,7 @@ sub match {
         $match = 1;
         last;
     }
-    return $match; 
+    return $match;
 }
 
 sub get {
@@ -56,7 +57,7 @@ sub get {
     }
     return undef unless $rhostclass;
 
-    (my $modulepath = $rhostclass) =~ s|::|/|g; 
+    (my $modulepath = $rhostclass) =~ s|::|/|g;
     require $modulepath.'.pm';
     return $rhostclass->get($argvs);
 }
@@ -103,7 +104,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2019 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2020 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
