@@ -4,43 +4,46 @@ use strict;
 use warnings;
 
 # https://technet.microsoft.com/en-us/library/bb232118
-my $StatusList = {
-    '4.3.1'  => [{ 'reason' => 'systemfull', 'string' => 'Insufficient system resources' }],
-    '4.3.2'  => [{ 'reason' => 'notaccept',  'string' => 'System not accepting network messages' }],
-    '4.4.2'  => [{ 'reason' => 'blocked',    'string' => 'Connection dropped' }],
-    '4.7.26' => [{
+state $StatusList = {
+    '4.3.1'   => [{ 'reason' => 'systemfull', 'string' => 'Insufficient system resources' }],
+    '4.3.2'   => [{ 'reason' => 'notaccept',  'string' => 'System not accepting network messages' }],
+    '4.4.2'   => [{ 'reason' => 'blocked',    'string' => 'Connection dropped' }],
+    '4.7.26'  => [{
         'reason' => 'securityerror',
         'string' => 'must pass either SPF or DKIM validation, this message is not signed'
     }],
-    '5.0.0'  => [{ 'reason' => 'blocked',     'string' => 'HELO / EHLO requires domain address' }],
-    '5.1.4'  => [{ 'reason' => 'systemerror', 'string' => 'Destination mailbox address ambiguous' }],
-    '5.2.1'  => [{ 'reason' => 'suspend',     'string' => 'Mailbox cannot be accessed' }],
-    '5.2.2'  => [{ 'reason' => 'mailboxfull', 'string' => 'Mailbox full' }],
-    '5.2.3'  => [{ 'reason' => 'exceedlimit', 'string' => 'Message too large' }],
-    '5.2.4'  => [{ 'reason' => 'systemerror', 'string' => 'Mailing list expansion problem' }],
-    '5.3.3'  => [{ 'reason' => 'systemfull',  'string' => 'Unrecognized command' }],
-    '5.3.4'  => [{ 'reason' => 'mesgtoobig',  'string' => 'Message too big for system' }],
-    '5.3.5'  => [{ 'reason' => 'systemerror', 'string' => 'System incorrectly configured' }],
-    '5.4.1'  => [{ 'reason' => 'rejected',    'string' => 'Recipient address rejected: Access denied' }],
-    '5.4.14' => [{ 'reason' => 'networkerror','string' => 'Hop count exceeded' }],
-    '5.5.2'  => [{ 'reason' => 'syntaxerror', 'string' => 'Send hello first' }],
-    '5.5.3'  => [{ 'reason' => 'syntaxerror', 'string' => 'Too many recipients' }],
-    '5.5.4'  => [{ 'reason' => 'filtered',    'string' => 'Invalid domain name' }],
-    '5.5.6'  => [{ 'reason' => 'contenterror','string' => 'Invalid message content' }],
-    '5.7.1'  => [
+    '5.0.0'   => [{ 'reason' => 'blocked',     'string' => 'HELO / EHLO requires domain address' }],
+    '5.1.4'   => [{ 'reason' => 'systemerror', 'string' => 'Destination mailbox address ambiguous' }],
+    '5.2.1'   => [{ 'reason' => 'suspend',     'string' => 'Mailbox cannot be accessed' }],
+    '5.2.2'   => [{ 'reason' => 'mailboxfull', 'string' => 'Mailbox full' }],
+    '5.2.3'   => [{ 'reason' => 'exceedlimit', 'string' => 'Message too large' }],
+    '5.2.4'   => [{ 'reason' => 'systemerror', 'string' => 'Mailing list expansion problem' }],
+    '5.2.122' => [{ 'reason' => 'toomanyconn', 'string' => 'The recipient has exceeded their limit for' }],
+    '5.3.3'   => [{ 'reason' => 'systemfull',  'string' => 'Unrecognized command' }],
+    '5.3.4'   => [{ 'reason' => 'mesgtoobig',  'string' => 'Message too big for system' }],
+    '5.3.5'   => [{ 'reason' => 'systemerror', 'string' => 'System incorrectly configured' }],
+    '5.4.1'   => [{ 'reason' => 'rejected',    'string' => 'Recipient address rejected: Access denied' }],
+    '5.4.11'  => [{ 'reason' => 'contenterror','string' => 'Agent generated message depth exceeded' }],
+    '5.4.14'  => [{ 'reason' => 'networkerror','string' => 'Hop count exceeded' }],
+    '5.5.2'   => [{ 'reason' => 'syntaxerror', 'string' => 'Send hello first' }],
+    '5.5.3'   => [{ 'reason' => 'syntaxerror', 'string' => 'Too many recipients' }],
+    '5.5.4'   => [{ 'reason' => 'filtered',    'string' => 'Invalid domain name' }],
+    '5.5.6'   => [{ 'reason' => 'contenterror','string' => 'Invalid message content' }],
+    '5.7.1'   => [
         { 'reason' => 'securityerror', 'string' => 'Delivery not authorized' },
         { 'reason' => 'securityerror', 'string' => 'Client was not authenticated' },
         { 'reason' => 'norelaying',    'string' => 'Unable to relay' },
     ],
-    '5.7.25'  => [{ 'reason' => 'blocked',      'string' => 'must have a reverse DNS record' }],
-    '5.7.506' => [{ 'reason' => 'blocked',      'string' => 'Bad HELO' }],
+    '5.7.25'  => [{ 'reason' => 'blocked', 'string' => 'must have a reverse DNS record' }],
+    '5.7.51'  => [{ 'reason' => 'blocked', 'string' => 'RestrictDomainsToIPAddresses or RestrictDomainsToCertificate' }],
+    '5.7.506' => [{ 'reason' => 'blocked', 'string' => 'Bad HELO' }],
     '5.7.508' => [{ 'reason' => 'toomanyconn',  'string' => 'has exceeded permitted limits within ' }],
     '5.7.509' => [{ 'reason' => 'rejected',     'string' => 'does not pass DMARC verification' }],
     '5.7.510' => [{ 'reason' => 'notaccept',    'string' => 'does not accept email over IPv6' }],
     '5.7.511' => [{ 'reason' => 'blocked',      'string' => 'banned sender' }],
     '5.7.512' => [{ 'reason' => 'contenterror', 'string' => 'message must be RFC 5322' }],
 };
-my $ReStatuses = {
+state $ReStatuses = {
     qr/\A4[.]4[.][17]\z/ => [
         { 'reason' => 'expired', 'string' => ['Connection timed out', 'Message expired'] }
     ],
@@ -88,7 +91,7 @@ my $ReStatuses = {
         { 'reason' => 'toomanyconn', 'string' => ['Access denied, tenant has exceeded threshold'] }
     ],
 };
-my $MessagesOf = {
+state $MessagesOf = {
     # Copied and converted from Sisimai::Lhost::Exchange2007
     'expired'       => ['QUEUE.Expired'],
     'hostunknown'   => ['SMTPSEND.DNS.NonExistentDomain'],
@@ -194,7 +197,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2016-2019 azumakuniyuki, All rights reserved.
+Copyright (C) 2016-2020 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
