@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # https://www.godaddy.com/help/what-does-my-email-bounceback-mean-3568
-my $ErrorCodes = {
+state $ErrorCodes = {
     'IB103' => 'blocked',       # 554 Connection refused. This IP has a poor reputation on Cloudmark Sender Intelligence (CSI). IB103
     'IB104' => 'blocked',       # 554 Connection refused. This IP is listed on the Spamhaus Block List (SBL). IB104
     'IB105' => 'blocked',       # 554 Connection refused. This IP is listed on the Exploits Block List (XBL). IB105
@@ -28,7 +28,7 @@ my $ErrorCodes = {
     'IB705' => 'virusdetected', # 552 Virus infected message rejected. IB705
 
 };
-my $MessagesOf = {
+state $MessagesOf = {
     'blocked'     => ['www.spamhaus.org/query/bl?ip=', '554 RBL Reject.'],
     'expired'     => ['Delivery timeout', "451 Sorry, I wasn't able to establish an SMTP connection."],
     'suspend'     => ['Account disabled'],
@@ -96,7 +96,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2017-2018 azumakuniyuki, All rights reserved.
+Copyright (C) 2017-2018,2020 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
