@@ -3,13 +3,13 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-my $StatusList = {
+state $StatusList = {
     # https://support.google.com/a/answer/3726730
     'X.1.1' => [{ 'reason' => 'userunknown', 'string' => ['The email account that you tried to reach does not exist.'] }],
     'X.1.2' => [{ 'reason' => 'hostunknown', 'string' => ["We weren't able to find the recipient domain."] }],
     'X.2.1' => [
-        { 'reason' => 'suspend',   'string' => ['The email account that you tried to reach is disabled.'] },
-        { 'reason' => 'undefined', 'string' => ['The user you are trying to contact is receiving mail ']  },
+        { 'reason' => 'suspend',     'string' => ['The email account that you tried to reach is disabled.'] },
+        { 'reason' => 'exceedlimit', 'string' => ['The user you are trying to contact is receiving mail ']  },
     ],
     'X.2.2' => [{ 'reason' => 'mailboxfull', 'string' => ['The email account that you tried to reach is over quota.'] }],
     'X.2.3' => [{ 'reason' => 'exceedlimit', 'string' => ["Your message exceeded Google's message size limits."] }],
@@ -148,7 +148,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016,2018-2019 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018-2020 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
